Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(360)

Unified Diff: blimp/engine/renderer/engine_image_serialization_processor.h

Issue 1859753002: Blimp: create Mojo component for renderer/browser communication. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: yzshen and nyquist feedback Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « blimp/engine/renderer/BUILD.gn ('k') | blimp/engine/renderer/engine_image_serialization_processor.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: blimp/engine/renderer/engine_image_serialization_processor.h
diff --git a/blimp/common/compositor/blimp_image_serialization_processor.h b/blimp/engine/renderer/engine_image_serialization_processor.h
similarity index 50%
copy from blimp/common/compositor/blimp_image_serialization_processor.h
copy to blimp/engine/renderer/engine_image_serialization_processor.h
index 040f24557be2b69780facc2ae5182739dd21d9a6..7aad7a0a81cb19a5545adec4905284faa305f0b3 100644
--- a/blimp/common/compositor/blimp_image_serialization_processor.h
+++ b/blimp/engine/renderer/engine_image_serialization_processor.h
@@ -2,29 +2,33 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef BLIMP_COMMON_COMPOSITOR_BLIMP_IMAGE_SERIALIZATION_PROCESSOR_H_
-#define BLIMP_COMMON_COMPOSITOR_BLIMP_IMAGE_SERIALIZATION_PROCESSOR_H_
+#ifndef BLIMP_ENGINE_RENDERER_ENGINE_IMAGE_SERIALIZATION_PROCESSOR_H_
+#define BLIMP_ENGINE_RENDERER_ENGINE_IMAGE_SERIALIZATION_PROCESSOR_H_
#include "base/macros.h"
#include "base/memory/scoped_ptr.h"
#include "blimp/common/blimp_common_export.h"
+#include "blimp/engine/mojo/blob_channel.mojom.h"
#include "cc/proto/image_serialization_processor.h"
#include "third_party/skia/include/core/SkPicture.h"
class SkPixelSerializer;
+namespace content {
+class RenderFrame;
+} // class content
+
namespace blimp {
+namespace engine {
-// BlimpImageSerializationProcessor provides functionality to serialize and
+// EngineImageSerializationProcessor provides functionality to serialize and
// deserialize Skia images.
-class BLIMP_COMMON_EXPORT BlimpImageSerializationProcessor
+class BLIMP_COMMON_EXPORT EngineImageSerializationProcessor
: public cc::ImageSerializationProcessor {
public:
- // Denotes whether the BlimpImageSerializationProcessor should act as a
- // serializer (engine) or deserializer (client).
- enum class Mode { SERIALIZATION, DESERIALIZATION };
- explicit BlimpImageSerializationProcessor(Mode mode);
- ~BlimpImageSerializationProcessor();
+ explicit EngineImageSerializationProcessor(
+ mojom::BlobChannelPtr blob_channel);
+ ~EngineImageSerializationProcessor();
// cc::ImageSerializationProcessor implementation.
SkPixelSerializer* GetPixelSerializer() override;
@@ -32,11 +36,12 @@ class BLIMP_COMMON_EXPORT BlimpImageSerializationProcessor
private:
scoped_ptr<SkPixelSerializer> pixel_serializer_;
- SkPicture::InstallPixelRefProc pixel_deserializer_;
+ mojom::BlobChannelPtr blob_channel_;
- DISALLOW_COPY_AND_ASSIGN(BlimpImageSerializationProcessor);
+ DISALLOW_COPY_AND_ASSIGN(EngineImageSerializationProcessor);
};
+} // namespace engine
} // namespace blimp
-#endif // BLIMP_COMMON_COMPOSITOR_BLIMP_IMAGE_SERIALIZATION_PROCESSOR_H_
+#endif // BLIMP_ENGINE_RENDERER_ENGINE_IMAGE_SERIALIZATION_PROCESSOR_H_
« no previous file with comments | « blimp/engine/renderer/BUILD.gn ('k') | blimp/engine/renderer/engine_image_serialization_processor.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698